<?php
/**
 * The page title part of the header
 *
 * @package gympress-pt
 */

$gympress_style_attr = '';

// Regular page id.
$gympress_bg_id        = get_the_ID();
$gympress_blog_id      = absint( get_option( 'page_for_posts' ) );
$gympress_shop_id      = absint( get_option( 'woocommerce_shop_page_id', 0 ) );

// If blog or single post use the ID of the blog.
if ( is_home() || is_singular( 'post' ) ) {
	$gympress_bg_id = $gympress_blog_id;
}

// If woocommerce page, use the shop page id.
if ( GymPressHelpers::is_woocommerce_active() && is_woocommerce() ) {
	$gympress_bg_id = $gympress_shop_id;
}

$show_title_area = get_field( 'show_title_area', $gympress_bg_id );
if ( ! $show_title_area ) {
	$show_title_area = 'yes';
}

$show_breadcrumbs = get_field( 'show_breadcrumbs', $gympress_bg_id );
if ( ! $show_breadcrumbs ) {
	$show_breadcrumbs = 'yes';
}

// Show/hide page title area (ACF control - single page && customizer control - all pages).
if ( 'yes' === $show_title_area && 'yes' === get_theme_mod( 'show_page_title_area', 'yes' ) ) :

	$gympress_style_attr = GymPressHelpers::page_header_background_style( $gympress_bg_id );

	?>

	<div class="page-header"<?php echo empty( $gympress_style_attr ) ? '' : ' style="' . esc_attr( $gympress_style_attr ) . ';"'; ?>>
		<div class="container">
			<?php
			$gympress_main_tag = 'h1';

			if ( is_home() || ( is_single() && 'post' === get_post_type() ) ) {
				$gympress_title    = 0 === $gympress_blog_id ? esc_html__( 'Blog', 'gympress-pt' ) : get_the_title( $gympress_blog_id );

				if ( is_single() ) {
					$gympress_main_tag = 'h2';
				}
			}
			elseif ( GymPressHelpers::is_woocommerce_active() && is_woocommerce() ) {
				ob_start();
				woocommerce_page_title();
				$gympress_title    = ob_get_clean();

				if ( is_product() ) {
					$gympress_main_tag = 'h2';
				}
			}
			elseif ( is_category() || is_tag() || is_author() || is_post_type_archive() || is_tax() || is_day() || is_month() || is_year() ) {
				$gympress_title = get_the_archive_title();
			}
			elseif ( is_search() ) {
				$gympress_title = esc_html__( 'Search Results For' , 'gympress-pt' ) . ' &quot;' . get_search_query() . '&quot;';
			}
			elseif ( is_404() ) {
				$gympress_title = esc_html__( 'Error 404' , 'gympress-pt' );
			}
			else {
				$gympress_title    = get_the_title();
			}

			?>

			<?php printf( '<%1$s class="page-header__title">%2$s</%1$s>', tag_escape( $gympress_main_tag ), wp_kses_post( $gympress_title ) ); ?>

			<?php
			if ( 'yes' === $show_breadcrumbs ) {
				get_template_part( 'template-parts/breadcrumbs' );
			}
			?>
		</div>
	</div>

<?php endif; ?>
